Returns a normalized operating-system label for the current R session. The result is a single lowercase string such as "windows", "mac", or "linux"; other Unix-like systems are normalized to their platform name.
Returns a normalized operating-system label for the current R session. The result is a single lowercase string such as "windows", "mac", or "linux"; other Unix-like systems are normalized to their platform name.