Get the RStudio version reported by the Windows installer registry entry
Source:R/programs.R
get_rstudio_version_from_registry.RdGet the RStudio version reported by the Windows installer registry entry
Value
A numeric_version() object, or NULL if not found.