Manage project lists.
get_path_recent_proj_list()– gets path to the file with the list of recent RStudio projects.get_path_user_proj_list()– gets path to the file with the list of personal RStudio projects.
open_recent_proj_list()– opens the file with the list of recent RStudio projects.
Usage
get_path_recent_proj_list()
get_path_user_proj_list(create = FALSE)
open_recent_proj_list()
open_user_proj_list()
update_rstudio_proj_list_user()Examples
if (interactive()) {
get_path_recent_proj_list()
get_path_user_proj_list()
}