read_projects()reads a project-list file and returns the project names and paths.
Examples
if (interactive()) {
read_projects(get_path_recent_proj_list())
}
read_projects() reads a project-list file and returns the project names and paths.
if (interactive()) {
read_projects(get_path_recent_proj_list())
}