Checks whether key tools are installed and, when online, reports the newest available versions for R, RStudio, and Quarto.
Examples
if (interactive()) {
check_installed_programs()
check_installed_programs("all")
}
Checks whether key tools are installed and, when online, reports the newest available versions for R, RStudio, and Quarto.
if (interactive()) {
check_installed_programs()
check_installed_programs("all")
}