Formats the installed and latest available version for an application or tool and reports whether the program is installed and whether an upgrade is known.
Usage
print_program_version_info(
name = "",
v_installed = NULL,
v_available = NULL,
type = "Program"
)Examples
if (interactive()) {
bio:::print_program_version_info("R", getRversion(), "4.5.0")
bio:::print_program_version_info("R", NULL, "4.5.0")
}