Reset RStudio keybindings to a packaged preset.
Source:R/settings--keybindings.R
rstudio_reset_keybindings.RdThis helper copies the packaged keybindings files into the user-level
RStudio folder, or removes the current keybinding files when the preset is
"rstudio-default".
Examples
if (interactive()) {
bio::rstudio_reset_keybindings(to = "bio-default")
bio::rstudio_reload_ui()
}